@@ -13,7 +13,6 @@ import (
 	"time"
 
 	"github.com/Rhymond/go-money"
-	"github.com/hashicorp/go-multierror"
 	"github.com/pkg/errors"
 	log "github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
@@ -112,11 +111,6 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		}
 	}
 
-	err = checkIfAllProjectsErrored(projects)
-	if err != nil {
-		return err
-	}
-
 	r, err := output.ToOutputFormat(projects)
 	if err != nil {
 		return err
@@ -133,7 +127,7 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	r.Currency = runCtx.Config.Currency
 	r.Metadata = output.NewMetadata(runCtx)
 
-	if runCtx.IsCloudUploadEnabled() {
+	if runCtx.IsCloudUploadExplicitlyEnabled() {
 		dashboardClient := apiclient.NewDashboardAPIClient(runCtx)
 		result, err := dashboardClient.AddRun(runCtx, r)
 		if err != nil {
@@ -191,46 +185,6 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	return nil
 }
 
-func checkIfAllProjectsErrored(projects []*schema.Project) error {
-	allError := true
-
-	if len(projects) == 0 {
-		allError = false
-	}
-
-	if len(projects) == 1 && len(projects[0].Metadata.Errors) == 1 {
-		return errors.New(projects[0].Metadata.Errors[0].Message)
-	}
-
-	for _, project := range projects {
-		if !project.Metadata.HasErrors() {
-			allError = false
-			break
-		}
-	}
-
-	if allError {
-		multi := &multierror.Error{}
-		for _, project := range projects {
-			msg := fmt.Sprintf("project %s errored: \n", project.Name)
-			for i, diag := range project.Metadata.Errors {
-				msg += "\t\t\t" + diag.Message
-
-				if i != len(project.Metadata.Errors)-1 {
-					msg += "\n"
-				}
-
-			}
-
-			multi.Errors = append(multi.Errors, errors.New(msg))
-		}
-
-		return multi
-	}
-
-	return nil
-}
-
 type projectOutput struct {
 	projects []*schema.Project
 }
@@ -250,7 +204,9 @@ func newParallelRunner(cmd *cobra.Command, runCtx *config.RunContext) (*parallel
 	// can't run multiple operations in parallel on the same path.
 	pathMuxs := map[string]*sync.Mutex{}
 	for _, projectCfg := range runCtx.Config.Projects {
-		pathMuxs[projectCfg.Path] = &sync.Mutex{}
+		if projectCfg.TerraformForceCLI {
+			pathMuxs[projectCfg.Path] = &sync.Mutex{}
+		}
 	}
 
 	var prior *output.Root
@@ -376,7 +332,7 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 		warn = v.Warn()
 	} else if err != nil {
 		m := fmt.Sprintf("%s\n\n", err)
-		m += fmt.Sprintf("Try setting --path to a Terraform plan JSON file. See %s for how to generate this.", ui.LinkString("https://infracost.io/troubleshoot"))
+		m += fmt.Sprintf("Try adding a config-file to configure how Infracost should run. See %s for details and examples.", ui.LinkString("https://infracost.io/config-file"))
 
 		return nil, clierror.NewCLIError(errors.New(m), "Could not detect path type")
 	}
@@ -421,7 +377,6 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 	}
 
 	// Load usage data
-	usageData := make(map[string]*schema.UsageData)
 	var usageFile *usage.UsageFile
 
 	if ctx.ProjectConfig.UsageFile != "" {
@@ -440,14 +395,12 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 				strings.Join(invalidKeys, ", "),
 			)
 		}
+
+		ctx.SetContextValue("hasUsageFile", true)
 	} else {
 		usageFile = usage.NewBlankUsageFile()
 	}
 
-	if len(usageData) > 0 {
-		ctx.SetContextValue("hasUsageFile", true)
-	}
-
 	// Merge wildcard usages into individual usage
 	wildCardUsage := make(map[string]*usage.ResourceUsage)
 	for _, us := range usageFile.ResourceUsages {
@@ -472,7 +425,7 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 		us.MergeResourceUsage(wildCardUsage[prefixName])
 	}
 
-	usageData = usageFile.ToUsageDataMap()
+	usageData := usageFile.ToUsageDataMap()
 	out := &projectOutput{}
 
 	t1 := time.Now()
@@ -584,7 +537,7 @@ func (r *parallelRunner) hasCloudResourceIDToUpload(projects []*schema.Project)
 }
 
 func (r *parallelRunner) buildResources(projects []*schema.Project) {
-	var projectPtrToUsageMap map[*schema.Project]map[string]*schema.UsageData
+	var projectPtrToUsageMap map[*schema.Project]schema.UsageMap
 	if r.runCtx.Config.UsageAPIEndpoint != "" {
 		projectPtrToUsageMap = r.fetchProjectUsage(projects)
 	}
@@ -592,7 +545,7 @@ func (r *parallelRunner) buildResources(projects []*schema.Project) {
 	schema.BuildResources(projects, projectPtrToUsageMap)
 }
 
-func (r *parallelRunner) fetchProjectUsage(projects []*schema.Project) map[*schema.Project]map[string]*schema.UsageData {
+func (r *parallelRunner) fetchProjectUsage(projects []*schema.Project) map[*schema.Project]schema.UsageMap {
 	coreResourceCount := 0
 	for _, project := range projects {
 		for _, partial := range project.PartialResources {
@@ -619,7 +572,7 @@ func (r *parallelRunner) fetchProjectUsage(projects []*schema.Project) map[*sche
 	spinner := ui.NewSpinner(fmt.Sprintf("Retrieving usage estimates for %s from Infracost Cloud", resourceStr), spinnerOpts)
 	defer spinner.Fail()
 
-	projectPtrToUsageMap := make(map[*schema.Project]map[string]*schema.UsageData, len(projects))
+	projectPtrToUsageMap := make(map[*schema.Project]schema.UsageMap, len(projects))
 
 	for _, project := range projects {
 		usageMap, err := prices.FetchUsageData(r.runCtx, project)
