@@ -5,7 +5,7 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"net/http"
 	"net/url"
 	"strconv"
@@ -217,7 +217,7 @@ func (h *gitlabPRHandler) CallCreateComment(ctx context.Context, body string) (C
 		defer res.Body.Close()
 	}
 
-	resBody, err := ioutil.ReadAll(res.Body)
+	resBody, err := io.ReadAll(res.Body)
 	if err != nil {
 		return nil, errors.Wrap(err, "Error reading response body")
 	}
@@ -367,7 +367,7 @@ func (h *gitlabCommitHandler) CallFindMatchingComments(ctx context.Context, tag
 			defer res.Body.Close()
 		}
 
-		resBody, err := ioutil.ReadAll(res.Body)
+		resBody, err := io.ReadAll(res.Body)
 		if err != nil {
 			return []Comment{}, errors.Wrap(err, "Error reading response body")
 		}
@@ -451,7 +451,7 @@ func (h *gitlabCommitHandler) CallCreateComment(ctx context.Context, body string
 		defer res.Body.Close()
 	}
 
-	resBody, err := ioutil.ReadAll(res.Body)
+	resBody, err := io.ReadAll(res.Body)
 	if err != nil {
 		return nil, errors.Wrap(err, "Error reading response body")
 	}
