@@ -7,10 +7,11 @@ import (
 )
 
 func TestDXConnectionGoldenFile(t *testing.T) {
-	t.Parallel()
 	if testing.Short() {
 		t.Skip("skipping test in short mode")
 	}
 
-	tftest.GoldenFileResourceTests(t, "dx_connection_test")
+	tftest.GoldenFileResourceTestsWithOpts(t, "dx_connection_test", &tftest.GoldenFileOptions{
+		CaptureLogs: true,
+	})
 }
