@@ -9,7 +9,6 @@ import (
 func getLambdaFunctionRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:      "aws_lambda_function",
-		Notes:     []string{"Provisioned concurrency is not yet supported."},
 		CoreRFunc: NewLambdaFunction,
 	}
 }
@@ -19,6 +18,8 @@ func NewLambdaFunction(d *schema.ResourceData) schema.CoreResource {
 	name := d.Get("function_name").String()
 	memorySize := int64(128)
 	architectures := string("x86_64")
+	storageSize := int64(512)
+
 	if d.Get("memory_size").Type != gjson.Null {
 		memorySize = d.Get("memory_size").Int()
 	}
@@ -27,11 +28,16 @@ func NewLambdaFunction(d *schema.ResourceData) schema.CoreResource {
 		architectures = d.Get("architectures.0").String()
 	}
 
+	if d.Get("ephemeral_storage").Type != gjson.Null {
+		storageSize = d.Get("ephemeral_storage.0.size").Int()
+	}
+
 	return &aws.LambdaFunction{
 		Address:      d.Address,
 		Region:       region,
 		Name:         name,
 		MemorySize:   memorySize,
 		Architecture: architectures,
+		StorageSize:  storageSize,
 	}
 }
