@@ -10,7 +10,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetAzureRMApplicationGatewayRegistryItem(),
 	getAppServiceEnvironmentRegistryItem(),
 	GetAzureRMAppIntegrationServiceEnvironmentRegistryItem(),
-	GetAzureRMAppFunctionRegistryItem(),
+	getFunctionAppRegistryItem(),
 	GetAzureRMAppNATGatewayRegistryItem(),
 	getAppServiceCertificateBindingRegistryItem(),
 	getAppServiceCertificateOrderRegistryItem(),
@@ -65,6 +65,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetAzureRMLoadBalancerRegistryItem(),
 	GetAzureRMLoadBalancerRuleRegistryItem(),
 	GetAzureRMLoadBalancerOutboundRuleRegistryItem(),
+	getLinuxFunctionAppRegistryItem(),
 	GetAzureRMLinuxVirtualMachineRegistryItem(),
 	GetAzureRMLinuxVirtualMachineScaleSetRegistryItem(),
 	getAzureRMLogAnalyticsWorkspaceRegistryItem(),
@@ -110,6 +111,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getDataFactoryIntegrationRuntimeSelfHostedRegistryItem(),
 	getLogAnalyticsSolutionRegistryItem(),
 	getMySQLFlexibleServerRegistryItem(),
+	getServicePlanRegistryItem(),
 	getSentinelDataConnectorAwsCloudTrailRegistryItem(),
 	getSentinelDataConnectorAzureActiveDirectoryRegistryItem(),
 	getSentinelDataConnectorAzureAdvancedThreatProtectionRegistryItem(),
@@ -121,9 +123,21 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getIoTHubRegistryItem(),
 	getIoTHubDPSRegistryItem(),
 	getVirtualNetworkPeeringRegistryItem(),
+	geWindowsFunctionAppRegistryItem(),
 	getPowerBIEmbeddedRegistryItem(),
 	getMSSQLElasticPoolRegistryItem(),
 	getSQLElasticPoolRegistryItem(),
+	getMonitorActionGroupRegistryItem(),
+	getMonitorDataCollectionRuleRegistryItem(),
+	getMonitorDiagnosticSettingRegistryItem(),
+	getMonitorMetricAlertRegistryItem(),
+	getMonitorScheduledQueryRulesAlertRegistryItem(),
+	getMonitorScheduledQueryRulesAlertV2RegistryItem(),
+	getApplicationInsightsStandardWebTestRegistryItem(),
+	getRecoveryServicesVaultRegistryItem(),
+	getBackupProtectedVmRegistryItem(),
+	getStorageQueueRegistryItem(),
+	getStorageShareRegistryItem(),
 }
 
 // FreeResources grouped alphabetically
@@ -341,16 +355,6 @@ var FreeResources = []string{
 	"azurerm_lb_nat_rule",
 	"azurerm_lb_probe",
 
-	// Azure Log Analytics
-	"azurerm_log_analytics_cluster_customer_managed_key",
-	"azurerm_log_analytics_data_export_rule",
-	"azurerm_log_analytics_datasource_windows_event",
-	"azurerm_log_analytics_datasource_windows_performance_counter",
-	"azurerm_log_analytics_linked_service",
-	"azurerm_log_analytics_linked_storage_account",
-	"azurerm_log_analytics_saved_search",
-	"azurerm_log_analytics_storage_insights",
-
 	// Azure Management
 	"azurerm_management_group",
 	"azurerm_management_group_subscription_association",
@@ -361,6 +365,41 @@ var FreeResources = []string{
 	"azurerm_managed_application",
 	"azurerm_managed_application_definition",
 
+	// Azure Monitor
+	"azurerm_monitor_aad_diagnostic_setting",
+	"azurerm_monitor_action_rule_action_group",
+	"azurerm_monitor_action_rule_suppression",
+	"azurerm_monitor_activity_log_alert",
+	"azurerm_monitor_alert_processing_rule_action_group",
+	"azurerm_monitor_alert_processing_rule_suppression",
+	"azurerm_monitor_autoscale_setting",
+	"azurerm_monitor_data_collection",
+	"azurerm_monitor_data_collection_rule_association",
+	"azurerm_monitor_log_profile",
+	"azurerm_monitor_private_link_scope",
+	"azurerm_monitor_private_link_scoped_service",
+	"azurerm_monitor_scheduled_query_rules_log",
+	"azurerm_monitor_smart_detector_alert_rule",
+
+	// Azure Monitor - Application Insights
+	"azurerm_application_insights_analytics_item",
+	"azurerm_application_insights_api_key",
+	"azurerm_application_insights_smart_detection_rule",
+	"azurerm_application_insights_workbook",
+	"azurerm_application_insights_workbook_template",
+
+	// Azure Monitor - Log Analytics
+	"azurerm_log_analytics_cluster_customer_managed_key",
+	"azurerm_log_analytics_data_export_rule",
+	"azurerm_log_analytics_datasource_windows_event",
+	"azurerm_log_analytics_datasource_windows_performance_counter",
+	"azurerm_log_analytics_linked_service",
+	"azurerm_log_analytics_linked_storage_account",
+	"azurerm_log_analytics_query_pack",
+	"azurerm_log_analytics_query_pack_query",
+	"azurerm_log_analytics_saved_search",
+	"azurerm_log_analytics_storage_insights",
+
 	// Azure Networking
 	"azurerm_application_security_group",
 	"azurerm_local_network_gateway",
@@ -446,9 +485,19 @@ var FreeResources = []string{
 	"azurerm_mssql_virtual_network_rule",
 
 	// Azure Storage
+	"azurerm_storage_account_customer_managed_key",
+	"azurerm_storage_account_local_user",
+	"azurerm_storage_account_network_rules",
+	"azurerm_storage_blob",
 	"azurerm_storage_blob_inventory_policy",
 	"azurerm_storage_container",
+	"azurerm_storage_data_lake_gen2_path",
 	"azurerm_storage_management_policy",
+	"azurerm_storage_object_replication",
+	"azurerm_storage_share_directory",
+	"azurerm_storage_share_file",
+	"azurerm_storage_sync_cloud_endpoint",
+	"azurerm_storage_sync_group",
 	"azurerm_storage_table_entity",
 
 	// Azure Virtual Desktop
@@ -458,6 +507,10 @@ var FreeResources = []string{
 	"azurerm_virtual_desktop_workspace_application_group_association",
 	"azurerm_virtual_desktop_host_pool",
 
+	// Azure Service Plan
+	"azurerm_windows_web_app",
+	"azurerm_linux_web_app",
+
 	// Azure Synapse Analytics
 	"azurerm_synapse_firewall_rule",
 	"azurerm_synapse_private_link_hub",
