@@ -39,7 +39,7 @@ func (p *PlanProvider) DisplayType() string {
 	return "Terraform plan binary file"
 }
 
-func (p *PlanProvider) LoadResources(usage map[string]*schema.UsageData) ([]*schema.Project, error) {
+func (p *PlanProvider) LoadResources(usage schema.UsageMap) ([]*schema.Project, error) {
 	j, err := p.generatePlanJSON()
 	if err != nil {
 		return []*schema.Project{}, err
