@@ -185,6 +185,7 @@ func resourceTestsForTfProject(t *testing.T, pName string, tfProject TerraformPr
 type GoldenFileOptions = struct {
 	Currency    string
 	CaptureLogs bool
+	IgnoreCLI   bool
 }
 
 func DefaultGoldenFileOptions() *GoldenFileOptions {
@@ -203,6 +204,10 @@ func GoldenFileResourceTestsWithOpts(t *testing.T, testName string, options *Gol
 		goldenFileResourceTestWithOpts(t, "hcl", testName, options)
 	})
 
+	if options != nil && options.IgnoreCLI {
+		return
+	}
+
 	t.Run("Terraform CLI", func(t *testing.T) {
 		goldenFileResourceTestWithOpts(t, "terraform", testName, options)
 	})
