@@ -4,11 +4,13 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/infracost/infracost/internal/logging"
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
 	"github.com/infracost/infracost/internal/usage"
 	"github.com/shopspring/decimal"
-	log "github.com/sirupsen/logrus"
+	"golang.org/x/text/cases"
+	"golang.org/x/text/language"
 )
 
 // StorageAccount represents Azure data storage services.
@@ -49,22 +51,28 @@ type StorageAccount struct {
 	EarlyDeletionGB                         *float64 `infracost_usage:"early_deletion_gb"`
 }
 
-// StorageAccountUsageSchema defines a list which represents the usage schema of StorageAccount.
-var StorageAccountUsageSchema = []*schema.UsageItem{
-	{Key: "storage_gb", DefaultValue: 0, ValueType: schema.Float64},
-	{Key: "monthly_iterative_read_operations", DefaultValue: 0, ValueType: schema.Int64},
-	{Key: "monthly_read_operations", DefaultValue: 0, ValueType: schema.Int64},
-	{Key: "monthly_iterative_write_operations", DefaultValue: 0, ValueType: schema.Int64},
-	{Key: "monthly_write_operations", DefaultValue: 0, ValueType: schema.Int64},
-	{Key: "monthly_list_and_create_container_operations", DefaultValue: 0, ValueType: schema.Int64},
-	{Key: "monthly_other_operations", DefaultValue: 0, ValueType: schema.Int64},
-	{Key: "monthly_data_retrieval_gb", DefaultValue: 0, ValueType: schema.Float64},
-	{Key: "monthly_data_write_gb", DefaultValue: 0, ValueType: schema.Float64},
-	{Key: "blob_index_tags", DefaultValue: 0, ValueType: schema.Int64},
-	{Key: "data_at_rest_storage_gb", DefaultValue: 0, ValueType: schema.Float64},
-	{Key: "snapshots_storage_gb", DefaultValue: 0, ValueType: schema.Float64},
-	{Key: "metadata_at_rest_storage_gb", DefaultValue: 0, ValueType: schema.Float64},
-	{Key: "early_deletion_gb", DefaultValue: 0, ValueType: schema.Float64},
+// CoreType returns the name of this resource type
+func (r *StorageAccount) CoreType() string {
+	return "StorageAccount"
+}
+
+func (r *StorageAccount) UsageSchema() []*schema.UsageItem {
+	return []*schema.UsageItem{
+		{Key: "storage_gb", DefaultValue: 0, ValueType: schema.Float64},
+		{Key: "monthly_iterative_read_operations", DefaultValue: 0, ValueType: schema.Int64},
+		{Key: "monthly_read_operations", DefaultValue: 0, ValueType: schema.Int64},
+		{Key: "monthly_iterative_write_operations", DefaultValue: 0, ValueType: schema.Int64},
+		{Key: "monthly_write_operations", DefaultValue: 0, ValueType: schema.Int64},
+		{Key: "monthly_list_and_create_container_operations", DefaultValue: 0, ValueType: schema.Int64},
+		{Key: "monthly_other_operations", DefaultValue: 0, ValueType: schema.Int64},
+		{Key: "monthly_data_retrieval_gb", DefaultValue: 0, ValueType: schema.Float64},
+		{Key: "monthly_data_write_gb", DefaultValue: 0, ValueType: schema.Float64},
+		{Key: "blob_index_tags", DefaultValue: 0, ValueType: schema.Int64},
+		{Key: "data_at_rest_storage_gb", DefaultValue: 0, ValueType: schema.Float64},
+		{Key: "snapshots_storage_gb", DefaultValue: 0, ValueType: schema.Float64},
+		{Key: "metadata_at_rest_storage_gb", DefaultValue: 0, ValueType: schema.Float64},
+		{Key: "early_deletion_gb", DefaultValue: 0, ValueType: schema.Float64},
+	}
 }
 
 // PopulateUsage parses the u schema.UsageData into the StorageAccount.
@@ -74,15 +82,10 @@ func (r *StorageAccount) PopulateUsage(u *schema.UsageData) {
 }
 
 // BuildResource builds a schema.Resource from valid StorageAccount data.
-// This method is called after the resource is initialised by an IaC provider.
+// This method is called after the resource is initialized by an IaC provider.
 func (r *StorageAccount) BuildResource() *schema.Resource {
-	if !r.isBlockBlobStorage() && !r.isFileStorage() && !r.isStorageV2() {
-		log.Warnf("Skipping resource %s. Infracost only supports StorageV2, BlockBlobStorage and FileStorage account kinds", r.Address)
-		return nil
-	}
-
 	if !r.isReplicationTypeSupported() {
-		log.Warnf("Skipping resource %s. %s %s doesn't support %s redundancy", r.Address, r.AccountKind, r.AccountTier, r.AccountReplicationType)
+		logging.Logger.Warnf("Skipping resource %s. %s %s doesn't support %s redundancy", r.Address, r.AccountKind, r.AccountTier, r.AccountReplicationType)
 		return nil
 	}
 
@@ -92,6 +95,11 @@ func (r *StorageAccount) BuildResource() *schema.Resource {
 		r.AccessTier = "Premium"
 	}
 
+	if r.isStorageV1() {
+		// StorageV1 doesn't support Hot or Cool storage.
+		r.AccessTier = "Standard"
+	}
+
 	costComponents := []*schema.CostComponent{}
 
 	costComponents = append(costComponents, r.storageCostComponents()...)
@@ -114,7 +122,7 @@ func (r *StorageAccount) BuildResource() *schema.Resource {
 
 	return &schema.Resource{
 		Name:           r.Address,
-		UsageSchema:    StorageAccountUsageSchema,
+		UsageSchema:    r.UsageSchema(),
 		CostComponents: costComponents,
 	}
 }
@@ -129,18 +137,35 @@ func (r *StorageAccount) buildProductFilter(meterName string) *schema.ProductFil
 			"Standard": "Blob Storage",
 			"Premium":  "Premium Block Blob",
 		}[r.AccountTier]
+	case r.isStorageV1():
+		productName = map[string]string{
+			"Standard": "General Block Blob",
+			"Premium":  "Premium Block Blob",
+		}[r.AccountTier]
 	case r.isStorageV2():
 		if r.NFSv3 {
 			productName = map[string]string{
 				"Standard": "General Block Blob v2 Hierarchical Namespace",
 				"Premium":  "Premium Block Blob v2 Hierarchical Namespace",
 			}[r.AccountTier]
+		} else if strings.EqualFold(r.AccountReplicationType, "lrs") && r.isHot() {
+			// For some reason the Azure pricing doesn't contain all the LRS costs for all regions under "General Block Blob v2" product name.
+			// But, the same pricing is available under "Blob Storage" product name.
+			productName = map[string]string{
+				"Standard": "Blob Storage",
+				"Premium":  "Premium Block Blob",
+			}[r.AccountTier]
 		} else {
 			productName = map[string]string{
 				"Standard": "General Block Blob v2",
 				"Premium":  "Premium Block Blob",
 			}[r.AccountTier]
 		}
+	case r.isBlobStorage():
+		productName = map[string]string{
+			"Standard": "Blob Storage",
+			"Premium":  "Premium Block Blob",
+		}[r.AccountTier]
 	case r.isFileStorage():
 		productName = map[string]string{
 			"Standard": "Files v2",
@@ -148,7 +173,7 @@ func (r *StorageAccount) buildProductFilter(meterName string) *schema.ProductFil
 		}[r.AccountTier]
 	}
 
-	skuName := fmt.Sprintf("%s %s", r.AccessTier, r.AccountReplicationType)
+	skuName := fmt.Sprintf("%s %s", cases.Title(language.English).String(r.AccessTier), strings.ToUpper(r.AccountReplicationType))
 
 	return &schema.ProductFilter{
 		VendorName:    strPtr("azure"),
@@ -172,6 +197,16 @@ func (r *StorageAccount) buildProductFilter(meterName string) *schema.ProductFil
 //	Standard Cool: cost exists
 //	Premium:       cost exists
 //
+// BlobStorage:
+//
+//	Standard Hot:  cost exists
+//	Standard Cool: cost exists
+//	Premium:       cost exists
+//
+// Storage:
+//
+// Standard: cost exists
+//
 // StorageV2:
 //
 //	Standard Hot:        cost exists
@@ -245,6 +280,11 @@ func (r *StorageAccount) storageCostComponents() []*schema.CostComponent {
 // Write Operations.
 //
 // BlockBlobStorage: n/a
+//
+// BlobStorage: n/a
+//
+// Storage: n/a
+//
 // StorageV2:
 //
 //	Standard Hot:        no cost
@@ -295,6 +335,16 @@ func (r *StorageAccount) iterativeWriteOperationsCostComponents() []*schema.Cost
 //	Standard Cool: cost exists
 //	Premium:       cost exists
 //
+// BlobStorage:
+//
+//	Standard Hot:  cost exists
+//	Standard Cool: cost exists
+//	Premium:       cost exists
+//
+// Storage:
+//
+// Standard: cost exists
+//
 // StorageV2:
 //
 //	Standard Hot:        cost exists
@@ -353,6 +403,16 @@ func (r *StorageAccount) writeOperationsCostComponents() []*schema.CostComponent
 //	Standard Cool: cost exists
 //	Premium:       cost exists
 //
+// BlobStorage:
+//
+//	Standard Hot:  cost exists
+//	Standard Cool: cost exists
+//	Premium:       cost exists
+//
+// Storage:
+//
+// Standard: cost exists
+//
 // StorageV2:
 //
 //	Standard Hot:        cost exists
@@ -408,6 +468,11 @@ func (r *StorageAccount) listAndCreateContainerOperationsCostComponents() []*sch
 // iterativeReadOperationsCostComponents returns a cost component for Iterative Read Operations.
 //
 // BlockBlobStorage: n/a
+//
+// BlobStorage: n/a
+//
+// Storage: n/a
+//
 // StorageV2:
 //
 //	Standard Hot:        no cost
@@ -458,6 +523,10 @@ func (r *StorageAccount) iterativeReadOperationsCostComponents() []*schema.CostC
 //	Standard Cool: cost exists
 //	Premium:       cost exists
 //
+// Storage:
+//
+// Standard: cost exists
+//
 // StorageV2:
 //
 //	Standard Hot:        cost exists
@@ -491,6 +560,11 @@ func (r *StorageAccount) readOperationsCostComponents() []*schema.CostComponent
 	if r.isStorageV2() && r.NFSv3 {
 		meterName = "(?<!Iterative) Read Operations"
 	}
+	if r.isStorageV1() && contains([]string{"RA-GRS"}, strings.ToUpper(r.AccountReplicationType)) {
+		// Storage V1 GRS/RA-GRS doesn't always have a Read Operations meter name, but we can
+		// use the Other Operations meter instead since it's the same price.
+		meterName = "Other Operations"
+	}
 
 	costComponents = append(costComponents, &schema.CostComponent{
 		Name:                 "Read operations",
@@ -515,6 +589,16 @@ func (r *StorageAccount) readOperationsCostComponents() []*schema.CostComponent
 //	Standard Cool: cost exists
 //	Premium:       cost exists
 //
+// BlobStorage:
+//
+//	Standard Hot:  cost exists
+//	Standard Cool: cost exists
+//	Premium:       cost exists
+//
+// Storage:
+//
+// Standard: cost exists
+//
 // StorageV2:
 //
 //	Standard Hot:        cost exists
@@ -545,6 +629,11 @@ func (r *StorageAccount) otherOperationsCostComponents() []*schema.CostComponent
 	}
 
 	meterName := "Other Operations"
+	if r.isStorageV1() {
+		// Most StorageV1 rows don't have a meter name called Other Operations,
+		// but they do have Delete Operations which is the same price.
+		meterName = "Delete Operations"
+	}
 
 	costComponents = append(costComponents, &schema.CostComponent{
 		Name:                 "All other operations",
@@ -570,6 +659,14 @@ func (r *StorageAccount) otherOperationsCostComponents() []*schema.CostComponent
 //	Standard Cool: cost exists
 //	Premium:       no cost
 //
+// BlobStorage:
+//
+//	Standard Hot:  no cost
+//	Standard Cool: cost exists
+//	Premium:       no cost
+//
+// Storage: n/a
+//
 // StorageV2:
 //
 //	Standard Hot:        no cost
@@ -622,6 +719,14 @@ func (r *StorageAccount) dataRetrievalCostComponents() []*schema.CostComponent {
 //	Standard Cool: cost exists
 //	Premium:       no cost
 //
+// BlobStorage:
+//
+//	Standard Hot:  no cost
+//	Standard Cool: cost exists
+//	Premium:       no cost
+//
+// Storage: n/a
+//
 // StorageV2:
 //
 //	Standard Hot:        no cost
@@ -639,7 +744,7 @@ func (r *StorageAccount) dataRetrievalCostComponents() []*schema.CostComponent {
 func (r *StorageAccount) dataWriteCostComponents() []*schema.CostComponent {
 	costComponents := []*schema.CostComponent{}
 
-	if !r.isBlockBlobStorage() || !r.isCool() {
+	if !(r.isBlockBlobStorage() && !r.isBlobStorage()) || !r.isCool() {
 		return costComponents
 	}
 
@@ -675,6 +780,14 @@ func (r *StorageAccount) dataWriteCostComponents() []*schema.CostComponent {
 //	Standard Cool: cost exists
 //	Premium:       no cost
 //
+// BlobStorage:
+//
+//	Standard Hot:  cost exists
+//	Standard Cool: cost exists
+//	Premium:       no cost
+//
+// Storage: n/a
+//
 // StorageV2:
 //
 //	Standard Hot:        cost exists
@@ -693,8 +806,9 @@ func (r *StorageAccount) blobIndexTagsCostComponents() []*schema.CostComponent {
 	costComponents := []*schema.CostComponent{}
 
 	isBlockPremium := r.isBlockBlobStorage() && r.isPremium()
+	isBlobPremium := r.isBlobStorage() && r.isPremium()
 	isV2NFSv3 := r.isStorageV2() && (r.NFSv3 || r.isPremium())
-	if r.isFileStorage() || isBlockPremium || isV2NFSv3 {
+	if r.isFileStorage() || r.isStorageV1() || isBlockPremium || isBlobPremium || isV2NFSv3 {
 		return costComponents
 	}
 
@@ -727,7 +841,13 @@ func (r *StorageAccount) blobIndexTagsCostComponents() []*schema.CostComponent {
 // File Storage.
 //
 // BlockBlobStorage: n/a
+//
+// BlobStorage: n/a
+//
+// Storage: n/a
+//
 // StorageV2: n/a
+//
 // FileStorage:
 //
 //	Standard Hot:  cost exists
@@ -769,7 +889,13 @@ func (r *StorageAccount) dataAtRestCostComponents() []*schema.CostComponent {
 // File Storage.
 //
 // BlockBlobStorage: n/a
+//
+// BlobStorage: n/a
+//
+// Storage: n/a
+//
 // StorageV2: n/a
+//
 // FileStorage:
 //
 //	Standard Hot:  cost exists
@@ -811,7 +937,13 @@ func (r *StorageAccount) snapshotsCostComponents() []*schema.CostComponent {
 // File Storage.
 //
 // BlockBlobStorage: n/a
+//
+// BlobStorage: n/a
+//
+// Storage: n/a
+//
 // StorageV2: n/a
+//
 // FileStorage:
 //
 //	Standard Hot:  cost exists
@@ -850,6 +982,11 @@ func (r *StorageAccount) metadataAtRestCostComponents() []*schema.CostComponent
 // File Storage.
 //
 // BlockBlobStorage: n/a
+//
+// BlobStorage: n/a
+//
+// Storage: n/a
+//
 // StorageV2:
 //
 //	Standard Hot:        no cost
@@ -867,7 +1004,7 @@ func (r *StorageAccount) metadataAtRestCostComponents() []*schema.CostComponent
 func (r *StorageAccount) earlyDeletionCostComponents() []*schema.CostComponent {
 	costComponents := []*schema.CostComponent{}
 
-	if r.isBlockBlobStorage() || !r.isCool() {
+	if r.isStorageV1() || r.isBlockBlobStorage() || r.isBlobStorage() || !r.isCool() {
 		return costComponents
 	}
 
@@ -920,6 +1057,14 @@ func (r *StorageAccount) isFileStorage() bool {
 	return strings.EqualFold(r.AccountKind, "filestorage")
 }
 
+func (r *StorageAccount) isBlobStorage() bool {
+	return strings.EqualFold(r.AccountKind, "blobstorage")
+}
+
+func (r *StorageAccount) isStorageV1() bool {
+	return strings.EqualFold(r.AccountKind, "storage")
+}
+
 func (r *StorageAccount) isStorageV2() bool {
 	return strings.EqualFold(r.AccountKind, "storagev2")
 }
@@ -943,13 +1088,19 @@ func (r *StorageAccount) isReplicationTypeSupported() bool {
 	case r.isPremium():
 		validReplicationTypes = []string{"LRS", "ZRS"}
 	case r.isBlockBlobStorage():
-		validReplicationTypes = []string{"LRS", "GRS", "RA-GRS", "ZRS"}
+		validReplicationTypes = []string{"LRS", "GRS", "RA-GRS"}
+	case r.isStorageV1():
+		validReplicationTypes = []string{"LRS", "ZRS", "GRS", "RA-GRS"}
+	case r.isStorageV2():
+		validReplicationTypes = []string{"LRS", "ZRS", "GRS", "RA-GRS", "GZRS", "RA-GZRS"}
+	case r.isBlobStorage():
+		validReplicationTypes = []string{"LRS", "GRS", "RA-GRS"}
 	case r.isFileStorage():
 		validReplicationTypes = []string{"LRS", "GRS", "ZRS"}
 	}
 
 	if validReplicationTypes != nil {
-		return contains(validReplicationTypes, r.AccountReplicationType)
+		return contains(validReplicationTypes, strings.ToUpper(r.AccountReplicationType))
 	}
 
 	return true
