@@ -13,7 +13,7 @@ type testResolver struct {
 	URL string
 }
 
-func (tr *testResolver) ResolveEndpoint(service, region string) (aws.Endpoint, error) {
+func (tr *testResolver) ResolveEndpoint(service, region string, options ...interface{}) (aws.Endpoint, error) {
 	return aws.Endpoint{
 		URL: tr.URL,
 	}, nil
@@ -29,7 +29,7 @@ func (tc *testCredentials) Retrieve(ctx context.Context) (aws.Credentials, error
 func WithTestEndpoint(ctx context.Context, url string) context.Context {
 	resolver := &testResolver{URL: url}
 	opts := []func(*config.LoadOptions) error{
-		config.WithEndpointResolver(resolver),
+		config.WithEndpointResolverWithOptions(resolver),
 		config.WithCredentialsProvider(&testCredentials{}),
 		// config.WithClientLogMode(aws.LogRequestWithBody | aws.LogResponseWithBody),
 	}
